use nxui::util::*;
use nxui::window::demowindow::DemoWindow;
fn main() {
    let win = DemoWindow::new();
    println!("{}",get_run_dir());
    println!("OS: {}",get_os());
    nxui::nxui::create_new_app(Box::new(win));
}
